summaryrefslogtreecommitdiff
path: root/gcc/tree-ssa-sink.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/tree-ssa-sink.c')
-rw-r--r--gcc/tree-ssa-sink.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/gcc/tree-ssa-sink.c b/gcc/tree-ssa-sink.c
index 7bb37187e20..b30c23d65f8 100644
--- a/gcc/tree-ssa-sink.c
+++ b/gcc/tree-ssa-sink.c
@@ -131,7 +131,7 @@ all_immediate_uses_same_place (tree stmt)
return true;
}
/* Some global stores don't necessarily have V_MAY_DEF's of global variables,
but we still must avoid moving them around. */
bool
@@ -156,7 +156,7 @@ is_hidden_global_store (tree stmt)
int x;
p_1 = (i_2 > 3) ? &x : p;
- # x_4 = V_MAY_DEF <x_3>
+ # x_4 = VDEF <x_3>
*p_1 = 5;
return 2;
@@ -194,7 +194,7 @@ is_hidden_global_store (tree stmt)
tree ptr = TREE_OPERAND (lhs, 0);
struct ptr_info_def *pi = SSA_NAME_PTR_INFO (ptr);
tree nmt = (pi) ? pi->name_mem_tag : NULL_TREE;
- tree smt = var_ann (SSA_NAME_VAR (ptr))->symbol_mem_tag;
+ tree smt = symbol_mem_tag (SSA_NAME_VAR (ptr));
/* If either the name tag or the symbol tag for PTR is a
global variable, then the store is necessary. */
@@ -207,6 +207,7 @@ is_hidden_global_store (tree stmt)
else
gcc_unreachable ();
}
+
return false;
}
@@ -402,7 +403,7 @@ statement_sink_location (tree stmt, basic_block frombb)
/* This will happen when you have
a_3 = PHI <a_13, a_26>
- a_26 = V_MAY_DEF <a_3>
+ a_26 = VDEF <a_3>
If the use is a phi, and is in the same bb as the def,
we can't sink it. */
@@ -131,7 +131,7 @@ all_immediate_uses_same_place (tree stmt)
return true;
}
-/* Some global stores don't necessarily have V_MAY_DEF's of global variables,
+/* Some global stores don't necessarily have VDEF's of global variables,
but we still must avoid moving them around. */
bool